//**************************************************************************//
//																			//
// File:		ISRs.c														//
//																			//
// Project:		ADSP-2191 Host Port booting									//
//																			//
// Description: This file contains the Interrupt Service Routines.			//
//																			//
//**************************************************************************//

#include "ADSP-2191 Host Port Booting.h"

//--------------------------------------------------------------------------//
// Function:	FlagA_ISR													//
//																			//
// Parameters:	iSignal (not used)											//
//					Number of interrupt										//
//																			//
// Return:		None														//
//																			//
// Description: This ISR is executed when the PLD signals an error.			//
//				The error is either a timeout (HACK is not asserted during	//
//				Host Port access) or an access from the Host while the		//
//				previous Host Port access was still ongoing.				//
//--------------------------------------------------------------------------//
void FlagA_ISR(int iSignal)
{
	// housekeeping for interrupt
	sysreg_write(sysreg_IOPG, General_Purpose_IO);
	io_space_write(FLAGC, ERROR_PF);			// clear pin, so interrupt doesn't occour again

	printf("Error signalled from PLD (no response from Target DSP)!\n");

	// error occured; stop program execution
	while(1);
}

